==> enterprisemodules-wls_config-3.17.0.tar.gz: enterprisemodules-wls_config-3.17.0/lib/puppet/type/wls_opatch/source.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'easy_type/source_dir'

newparam(:source, :parent => EasyType::SourceDir) do
  defaultto ''
  isrequired

  def custom_action
    return if resource.patch_type == 'single'

    Puppet.debug 'Unzipping individual patch zips in spb patch if needed.'
    #
    # If the patch is a spb patch, process all zips in the
    # zip before passing on
    #
    spb_patch_list.each do |patch|
      if /\.zip$/.match?(patch)
        unzip("#{spb_root}/#{patch}", @value, resource.os_user, nil)
      else
        Puppet.debug "No unzip needed for #{patch}."
      end
    end
  end

  def spb_root
    spb_patchlist_file.split("/#{spb_architecture}_patchlist.txt").first
  end

  def spb_patch_list
    File.read(spb_patchlist_file).split
  end

  def spb_patchlist_file
    found_files = Dir["#{@value}/**/binary_patches/#{spb_architecture}_patchlist.txt"]
    raise "SPB zip file doesn't contain file 'binary_patches/#{spb_architecture}_patchlist.txt'" if found_files.empty?
    raise "SPB zip file doesn't contains multile 'binary_patches/#{spb_architecture}_patchlist.txt'" if found_files.size > 1

    found_files.first
  end

  def spb_architecture
    kernel = Facter.value(:kernel)
    os_hardware = Facter.value(:os)['hardware']
    case kernel
    when 'Linux'
      case os_hardware
      when 'x86_64'
        'linux64'
      else
        fail "spb patching not (yet) supported on #{os_hardware}."
      end
    else
      fail "spb patching not (yet) supported on #{os_hardware}."
    end
  end
end

==> enterprisemodules-wls_config-3.17.1.tar.gz: enterprisemodules-wls_config-3.17.1/lib/puppet/type/wls_opatch/source.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'easy_type/source_dir'

newparam(:source, :parent => EasyType::SourceDir) do
  defaultto ''
  isrequired

  def custom_action
    return if resource.patch_type == 'single'

    Puppet.debug 'Unzipping individual patch zips in spb patch if needed.'
    #
    # If the patch is a spb patch, process all zips in the
    # zip before passing on
    #
    spb_patch_list.each do |patch|
      if /\.zip$/.match?(patch) && fetched?
        unzip("#{spb_root}/#{patch}", @value, resource.os_user, nil)
      else
        Puppet.debug "No unzip needed for #{patch}."
      end
      # Set the final directory where opatch searches
      found_dir = Dir.glob("#{@value}/**/binary_patches/#{patch}#{resource[:patch_id]}").first
      @value = found_dir.gsub("/#{resource[:patch_id]}",'') unless found_dir.nil? # Return the value without the patch dir itself
    end
    @value
  end

  def spb_root
    spb_patchlist_file.split("/#{spb_architecture}_patchlist.txt").first
  end

  def spb_patch_list
    File.read(spb_patchlist_file).split
  end

  def spb_patchlist_file
    found_files = Dir["#{@value}/**/binary_patches/#{spb_architecture}_patchlist.txt"]
    raise "SPB zip file doesn't contain file 'binary_patches/#{spb_architecture}_patchlist.txt'" if found_files.empty?
    raise "SPB zip file doesn't contains multile 'binary_patches/#{spb_architecture}_patchlist.txt'" if found_files.size > 1

    found_files.first
  end

  def spb_architecture
    kernel = Facter.value(:kernel)
    os_hardware = Facter.value(:os)['hardware']
    case kernel
    when 'Linux'
      case os_hardware
      when 'x86_64'
        'linux64'
      else
        fail "spb patching not (yet) supported on #{os_hardware}."
      end
    else
      fail "spb patching not (yet) supported on #{os_hardware}."
    end
  end
end
